@@ -1,3 +1,5 @@
+"""The bar prompt for xonsh shell with customizable sections and Starship support. """
+
 import os
 import re
 import time
@@ -12,7 +14,7 @@ Themes:
 _pb_themes = {
     'default': {
         'left': '{hostname}{user}{cwd_abs#accent}',
-        'right': '{env_name#strip_brackets#section}{date_time_tz}', # Temporary removed {gitstatus#nocolorx#section}
+        'right': '{env_name#strip#strip_brackets#section}{date_time_tz}', # Temporary removed {gitstatus#nocolorx#section}
         'bar_bg': '{BACKGROUND_#323232}',
         'bar_fg': '{#AAA}',
         'section_bg': '{BACKGROUND_#444}',
@@ -157,8 +159,11 @@ def _prompt_bar():
 
 @events.on_postcommand
 def _(cmd, rtn, **kwargs):
-    if rtn != 0 and __xonsh__.env.get('XONTRIB_PROMPT_BAR_SHOW_RETURN', True):
-        printx(f"{{RED}}Return {rtn}{{RESET}}\n")
+    if rtn not in [0, -8888] and __xonsh__.env.get('XONTRIB_PROMPT_BAR_SHOW_RETURN', True):
+        color = 'RED'
+        if rtn == -2:  # Ctrl+C in Linux
+            color = 'YELLOW'
+        printx(f"{{{color}}}Return {rtn}{{RESET}}\n")
     else:
         print('')
 
